@@ -7,6 +7,9 @@ from dtschema.lib import (
     DTValidator,
     format_error,
     extract_compatibles,
+    extract_types,
+    get_prop_types,
+    sized_int,
 )
 
 from dtschema.version import (
